# nkunyim_util
Nkunyim utilities for common operations


## Virtual Environment
sudo apt install python3.12-venv
sudo python3.12 -m venv ~/devspace/env/package
source ~/devspace/env/package/bin/activate
sudo chmod -R a+rwx ~/devspace/env/package